# GCGC

> GCGC is a python package for feature processing on Biological Sequences.

[![](https://img.shields.io/pypi/v/gcgc.svg)](https://pypi.python.org/pypi/gcgc)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2329966.svg)](https://doi.org/10.5281/zenodo.2329966)

## Installation

Install GCGC via pip:

```sh
$ pip install gcgc
```

## Documentation

The GCGC documentation is at [gcgc.trenthauck.com](http://gcgc.trenthauck.com),
please see it for an example.

## Citing GCGC

If you use GCGC in your research, cite it with the following:

```
@misc{trent_hauck_2018_2329966,
  author       = {Trent Hauck},
  title        = {GCGC},
  month        = dec,
  year         = 2018,
  doi          = {10.5281/zenodo.2329966},
  url          = {https://doi.org/10.5281/zenodo.2329966}
}
```
